Output

Struct Output 

pub struct Output { /* private fields */ }
Copied from redox_log crate with some modifications, in future we might use it instead? An output that will be logged to. The two major outputs for most Redox system programs are usually the log file, and the global stdout.